pub struct ReadResult { /* private fields */ }Expand description
Result of a ranked read operation
Contains the write rank and value at the time of the read. The read also installs a fence at the given rank, preventing lower-ranked writes from succeeding.
Implementations
Sourceimpl ReadResult
impl ReadResult